@@ -13,7 +13,7 @@ use HTTP::Date;
 use HTTP::Status qw{ :constants };
 use Test::More 0.96;	# For subtest
 
-our $VERSION = '0.144_01';
+our $VERSION = '0.145_01';
 
 # Set the following to zero if Space Track (or any other SSL host)
 # starts using a certificate that can not be verified.
@@ -205,7 +205,7 @@ sub not_defined {
 		url	=> 'https://spaceflight.nasa.gov/realdata/elements/index.html'
 	    },
 	    'www.amsat.org'	=> {
-		url	=> 'http://www.amsat.org/',
+		url	=> 'https://www.amsat.org/',
 	    },
 	    'www.space-track.org'	=> {
 		url	=> 'https://www.space-track.org/',
@@ -266,6 +266,7 @@ sub not_defined {
 	}
 
 	$ua ||= LWP::UserAgent->new(
+	    agent	=> 'curl/7.77.0',
 	    ssl_opts	=> { verify_hostname => VERIFY_HOSTNAME },
 	);
 	my $rslt = $ua->get( $url );
